searchNodes=[{"doc":"This module allows using data placed in POSIX shared memory on POSIX compliant systems. Defines a struct representing the actual shared memory object. The struct should not be modified, and should always be passed around as a whole - see Shmex.t/0","ref":"Shmex.html","title":"Shmex","type":"module"},{"doc":"Creates a new, empty shared memory area with the given capacity","ref":"Shmex.html#empty/1","title":"Shmex.empty/1","type":"function"},{"doc":"Ensures that shared memory is not garbage collected at the point of executing this function. Useful when passing shared memory to other OS process, to prevent it from being garbage collected until received and mapped by that process.","ref":"Shmex.html#ensure_not_gc/1","title":"Shmex.ensure_not_gc/1","type":"function"},{"doc":"Creates a new shared memory area filled with the existing data.","ref":"Shmex.html#new/1","title":"Shmex.new/1","type":"function"},{"doc":"Creates a new shared memory area initialized with data and sets its capacity. The actual capacity is the greater of passed capacity and data size","ref":"Shmex.html#new/2","title":"Shmex.new/2","type":"function"},{"doc":"Sets the capacity of shared memory area. If the capacity is smaller than the current size, data will be discarded and size modified","ref":"Shmex.html#set_capacity/2","title":"Shmex.set_capacity/2","type":"function"},{"doc":"Returns shared memory contents as a binary.","ref":"Shmex.html#to_binary/1","title":"Shmex.to_binary/1","type":"function"},{"doc":"Struct describing data kept in shared memory. Should not be modified and should always be passed around as a whole ...including passing to the native code - there are functions in :shmex_lib (a native library exported via Bundlex) that will allow to transorm Elixir struct into a C struct and then access the shared memory from the native code.) Shared memory should be available as long as the associated struct is not garbage collected.","ref":"Shmex.html#t:t/0","title":"Shmex.t/0","type":"type"},{"doc":"This module provides natively implemented functions allowing low-level operations on Posix shared memory. Use with caution!","ref":"Shmex.Native.html","title":"Shmex.Native","type":"module"},{"doc":"Creates guard for existing shared memory. This function should be only used when Shmex struct was created by some other NIF and even though the SHM exists, it&#39;s guard field is set to nil. Trying to use it with SHM obtained via allocate/1 will result in error. See also docs for allocate/1","ref":"Shmex.Native.html#add_guard/1","title":"Shmex.Native.add_guard/1","type":"function"},{"doc":"Creates shared memory segment and adds a guard for it. The guard associated with this memory segment is placed in returned Shmex struct. When the guard resource is deallocated by BEAM, the shared memory is unlinked and will disappear from the system when last process using it unmaps it","ref":"Shmex.Native.html#allocate/1","title":"Shmex.Native.allocate/1","type":"function"},{"doc":"Concatenates two shared memory areas by appending the data from the second at the end of the first one. Fails with {:error, {:einval, :ftruncate}} if OS does not support changing shared memory capacity. The first shared memory is a target that will contain data from both shared memory areas. Its capacity will be set to the sum of sizes of both shared memory areas. The second one, the source, will remain unmodified.","ref":"Shmex.Native.html#append/2","title":"Shmex.Native.append/2","type":"function"},{"doc":"Ensures that shared memory is not garbage collected at the point of executing this function. Useful when passing shared memory to other OS process, to prevent it from being garbage collected until received and mapped by that process.","ref":"Shmex.Native.html#ensure_not_gc/1","title":"Shmex.Native.ensure_not_gc/1","type":"function"},{"doc":"Reads the contents of shared memory and returns it as a binary.","ref":"Shmex.Native.html#read/1","title":"Shmex.Native.read/1","type":"function"},{"doc":"Reads cnt bytes from the shared memory and returns it as a binary. cnt should not be greater than shm.size","ref":"Shmex.Native.html#read/2","title":"Shmex.Native.read/2","type":"function"},{"doc":"Sets the capacity of shared memory area and updates the Shmex struct accordingly.","ref":"Shmex.Native.html#set_capacity/2","title":"Shmex.Native.set_capacity/2","type":"function"},{"doc":"Splits the contents of shared memory area into two by moving the data past the specified position into a new shared memory. shm has to be an existing shared memory (obtained via allocate/1). It virtually trims the existing shared memory to position bytes by setting size to position (The actual data is still present) and the overlapping data is copied into the new shared memory area.","ref":"Shmex.Native.html#split_at/2","title":"Shmex.Native.split_at/2","type":"function"},{"doc":"Trims shared memory capacity to match its size.","ref":"Shmex.Native.html#trim/1","title":"Shmex.Native.trim/1","type":"function"},{"doc":"Drops bytes bytes from the beggining of shared memory area and trims it to match the new size.","ref":"Shmex.Native.html#trim/2","title":"Shmex.Native.trim/2","type":"function"},{"doc":"Writes the binary into the shared memory. Overwrites the existing content. Increases the capacity of shared memory to fit the data.","ref":"Shmex.Native.html#write/2","title":"Shmex.Native.write/2","type":"function"},{"doc":"Shmex Shmex is a library providing Elixir bindings for shared memory and native functions to manipulate it in NIFs. Documentation is available at HexDocs The source code is available at GitHub","ref":"readme.html","title":"Shmex","type":"extras"},{"doc":"Add the following line to your deps in mix.exs. Run mix deps.get. {:shmex, &quot;~&gt; 0.2.0&quot;} All native stuff is exported as :libBundlex dependency. To import, add the following line to your nif specification in bundlex.exs deps: [shmex: :lib] and another one in your native header file #import &lt;shmex/lib.h&gt;","ref":"readme.html#installation","title":"Shmex - Installation","type":"extras"},{"doc":"To execute tests run mix test. These test tags are excluded by default: shm_tmpfs - tests that require access to information about shared memory segments present in the OS via tmpfs, not supported e.g. by Mac OS shm_resizable - tests for functions that involve resizing existing shared memory segments, not supported e.g. by Mac OS","ref":"readme.html#testing","title":"Shmex - Testing","type":"extras"},{"doc":"Copyright 2018, Software Mansion Licensed under the Apache License, Version 2.0","ref":"readme.html#copyright-and-license","title":"Shmex - Copyright and License","type":"extras"}]